@@ -32,7 +32,7 @@ from gateways.common.cs18_api_responses import (AccountStatusResponse, Blueprint
                                                 BlueprintValidationResponse, AccountRepositoryDetailsResponse,
                                                 DirectAwsSshResponse, DirectAzureSshResponse, DirectRdpResponse,
                                                 ParameterStoreItem, RepositoryProviderResponse,
-                                                RepositoryRelationshipResponse, AccountExtraDetails,
+                                                RepositoryRelationshipResponse, AccountExtraDetails, CustomTagResponse,
                                                 TerraformModuleDescriptorResponse)
 from gateways.n_session import NSession
 from gateways.the_gateway import TheGateway
@@ -842,6 +842,36 @@ class Colony:
         GatewayUtils.handle_response(response=resp, return_codes=[200])
         return resp.content
 
+    def get_prepatetags_file(self, sandbox_id: str, service_name: str) -> bytes:
+        method_url = self._api_root.sandbox.sandbox_preparetags(sandbox_id=sandbox_id, service_name=service_name)
+        resp = self.session.get(url=method_url)
+        GatewayUtils.handle_response(response=resp, return_codes=[200])
+        return resp.content
+
+    def get_tfinit_file(self, sandbox_id: str, service_name: str) -> bytes:
+        method_url = self._api_root.sandbox.sandbox_tfinit(sandbox_id=sandbox_id, service_name=service_name)
+        resp = self.session.get(url=method_url)
+        GatewayUtils.handle_response(response=resp, return_codes=[200])
+        return resp.content
+
+    def get_tfplan_file(self, sandbox_id: str, service_name: str) -> bytes:
+        method_url = self._api_root.sandbox.sandbox_tfplan(sandbox_id=sandbox_id, service_name=service_name)
+        resp = self.session.get(url=method_url)
+        GatewayUtils.handle_response(response=resp, return_codes=[200])
+        return resp.content
+
+    def get_tfapply_file(self, sandbox_id: str, service_name: str) -> bytes:
+        method_url = self._api_root.sandbox.sandbox_tfapply(sandbox_id=sandbox_id, service_name=service_name)
+        resp = self.session.get(url=method_url)
+        GatewayUtils.handle_response(response=resp, return_codes=[200])
+        return resp.content
+
+    def get_tfdestroy_file(self, sandbox_id: str, service_name: str) -> bytes:
+        method_url = self._api_root.sandbox.sandbox_tfdestroy(sandbox_id=sandbox_id, service_name=service_name)
+        resp = self.session.get(url=method_url)
+        GatewayUtils.handle_response(response=resp, return_codes=[200])
+        return resp.content
+
     def validate_blueprint(self, blueprint: str, deployment_type: str = 'sandbox', branch: str = None,
                            commit: str = None) -> BlueprintValidationResponse:
         method_url = self._api_root.blueprint_validation.blueprint_validation_by_space_name(space_name=self.space)
@@ -1136,6 +1166,12 @@ class Colony:
         response = self.session.post(url=method_url, json=request)
         GatewayUtils.handle_response(response=response, return_codes=[200])
 
+    def get_account_cost_breakdown(self, frm: datetime, until: datetime, criteria: str = 'blueprint') -> dict:
+        url = self._api_root.account_cost.breakdown(frm=frm, until=until, criteria=criteria)
+        response = self.session.get(url=url)
+        GatewayUtils.handle_response(response, [200])
+        return json.loads(response.text)
+
     def get_cost_breakdown(self, frm: datetime, until: datetime, criteria: str = 'blueprint') -> dict:
         url = self._api_root.cost.breakdown(space_name=self.space, frm=frm, until=until, criteria=criteria)
         response = self.session.get(url=url)
@@ -1495,6 +1531,43 @@ class Colony:
         GatewayUtils.handle_response(response=res, return_codes=[200])
         return json.loads(res.text)
 
+    def get_custom_tags(self) -> List[CustomTagResponse]:
+        method_url = self._api_root.settings.custom_tags()
+        res = self.session.get(url=method_url)
+        GatewayUtils.handle_response(response=res, return_codes=[200])
+        custom_tags_json = json.loads(res.text)
+        return [Converters.create_custom_tag_response(custom_tag) for custom_tag in custom_tags_json]
+
+    def create_custom_tag(self, name: str, value: str, scope: str, possible_values: [], description: str):
+        method_url = self._api_root.settings.custom_tags()
+        request = {
+            "name": name,
+            "value": value,
+            "scope": scope,
+            "possible_values": possible_values,
+            "description": description
+        }
+        res = self.session.post(url=method_url, json=request)
+        GatewayUtils.handle_response(response=res, return_codes=[200])
+
+    def update_custom_tag(self, old_name: str, name: str, value: str, scope: str, possible_values: [],
+                          description: str):
+        method_url = self._api_root.settings.custom_tag(old_name)
+        request = {
+            "name": name,
+            "value": value,
+            "scope": scope,
+            "possible_values": possible_values,
+            "description": description
+        }
+        res = self.session.put(url=method_url, json=request)
+        GatewayUtils.handle_response(response=res, return_codes=[200])
+
+    def delete_custom_tag(self, name: str):
+        method_url = self._api_root.settings.custom_tag(name)
+        res = self.session.delete(url=method_url)
+        GatewayUtils.handle_response(response=res, return_codes=[200])
+
 
 class SandboxesHandler:
     def __init__(self):
