@@ -42,7 +42,8 @@ from gateways.common.cs18_api_responses import (GetSpacesResponse, CreateAccount
                                                 BlueprintValidationResponse, ArtifactRepoCreatedUser,
                                                 ArtifactRepoResponse, CatalogForGetAllResponse, CatalogForGetResponse,
                                                 SpaceCloudAccount, SpaceAdmin, SandboxOutput, ServiceTfProgressResponse,
-                                                TerraformModuleDescriptorResponse)
+                                                TerraformModuleDescriptorResponse, CustomTagResponse,
+                                                ServiceTfLogsResponse, ServiceTfLogInfo)
 
 
 class Converters:
@@ -849,6 +850,7 @@ class Converters:
             repository_id=repo["id"],
             name=repo["name"],
             provider_id=repo["provider_id"],
+            provider_name=repo["provider_name"],
             allow_sharing=repo["allow_sharing"],
             open_access=repo["open_access"],
             account_id=repo["account_id"],
@@ -928,20 +930,66 @@ class Converters:
 
     @staticmethod
     def _create_service_response(service: dict) -> ServiceResponse:
-        progress_dict = service["progress"]
-        if progress_dict:
-            progress = ServiceTfProgressResponse(tf_plan_status=progress_dict["terraform_plan"],
-                                                 tf_apply_status=progress_dict["terraform_apply"],
-                                                 tf_destroy_status=progress_dict["terraform_destroy"])
-        else:
-            progress = None
         return ServiceResponse(
             name=service["name"],
             status=service["status"],
             service_type=service["type"],
-            progress=progress
+            progress=Converters._create_progress_response(service["progress"]),
+            logs=Converters._create_tf_logs_response(service["logs"])
         )
 
+    @staticmethod
+    def _create_tf_logs_response(logs_dict: dict) -> Optional[ServiceTfLogsResponse]:
+        if logs_dict is None:
+            return None
+
+        tf_tagging_dict = logs_dict["preparetags"]
+        if tf_tagging_dict:
+            tf_tagging = ServiceTfLogInfo(location=tf_tagging_dict["location"])
+        else:
+            tf_tagging = None
+
+        tf_init_dict = logs_dict["tfinit"]
+        if tf_init_dict:
+            tf_init = ServiceTfLogInfo(location=tf_init_dict["location"])
+        else:
+            tf_init = None
+
+        tf_plan_dict = logs_dict["tfplan"]
+        if tf_plan_dict:
+            tf_plan = ServiceTfLogInfo(location=tf_plan_dict["location"])
+        else:
+            tf_plan = None
+
+        tf_apply_dict = logs_dict["tfapply"]
+        if tf_apply_dict:
+            tf_apply = ServiceTfLogInfo(location=tf_apply_dict["location"])
+        else:
+            tf_apply = None
+
+        tf_destroy_dict = logs_dict["tfdestroy"]
+        if tf_destroy_dict:
+            tf_destroy = ServiceTfLogInfo(location=tf_destroy_dict["location"])
+        else:
+            tf_destroy = None
+
+        return ServiceTfLogsResponse(tf_tagging=tf_tagging,
+                                     tf_init=tf_init,
+                                     tf_plan=tf_plan,
+                                     tf_apply=tf_apply,
+                                     tf_destroy=tf_destroy)
+
+    @staticmethod
+    def _create_progress_response(progress_dict: dict) -> Optional[ServiceTfProgressResponse]:
+        if progress_dict is None:
+            return None
+
+        return ServiceTfProgressResponse(tf_tagging_status=progress_dict["prepare_tags"],
+                                         tf_init_status=progress_dict["terraform_init"],
+                                         tf_plan_status=progress_dict["terraform_plan"],
+                                         tf_apply_status=progress_dict["terraform_apply"],
+                                         tf_destroy_status=progress_dict["terraform_destroy"])
+
     @staticmethod
     def _create_launching_progress(progress: dict) -> Optional[LaunchingProgress]:
         if not progress:
@@ -1096,6 +1144,20 @@ class Converters:
             last_name=data['last_name']
         )
 
+    @staticmethod
+    def create_custom_tag_response(data: dict) -> CustomTagResponse:
+        return CustomTagResponse(
+            name=data['name'],
+            value=data['value'],
+            scope=data['scope'],
+            possible_values=data['possible_values'],
+            description=data['description'],
+            modified_by=data['modified_by'],
+            last_modified=data['last_modified'],
+            created_by=data['created_by'],
+            created_date=data['created_date']
+        )
+
     @staticmethod
     def _create_sandbox_outputs(data: Optional[List]) -> Optional[List[SandboxOutput]]:
         if data is None:
