@@ -119,3 +119,19 @@ class NewUserSurveyRequest:
         self.roles = roles if roles is not None else []
         self.primary_technologies = primary_technologies if primary_technologies is not None else []
         self.primary_platforms = primary_platforms if primary_platforms is not None else []
+
+
+class CustomTagRequest:
+    def __init__(
+            self,
+            name: str,
+            value: str,
+            scope: str,
+            possible_values: [],
+            description: str,
+    ):
+        self.name = name
+        self.value = value
+        self.scope = scope
+        self.possible_values = possible_values
+        self.description = description
